@@ -96,10 +96,15 @@ objSize.default <- function(x, quick = FALSE, ...) {
 objSize.list <- function(x, quick = FALSE, ...) {
   os <- obj_size(x) # need to get overall object size; not just elements;
   # but this doesn't work for e.g., terra
+
   if (!quick) {
     out <- lapply(x, objSize, quick = quick)
+    os2 <- sum(unlist(out))
+    os <- max(os2, os)
+    class(os) <- "lobstr_bytes"
     attr(os, "objSize") <- out
   }
+
   os
 }
 
